@@ -64,8 +64,8 @@ public:
 
 public:
 
-    explicit ModelHelper(QObject* const parent = 0);
-    virtual ~ModelHelper();
+    explicit ModelHelper(QObject* const parent = nullptr);
+    ~ModelHelper() override;
 
     void snapItemsTo(const QModelIndex& targetIndex, const QList<QPersistentModelIndex>& snappedIndices);
 
